/*
 ******************************************************************************
 * Copyright (C) 2005-2013 Alfresco Software Limited.
 * 
 * This file is part of the Alfresco Mobile SDK.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *  
 *  http://www.apache.org/licenses/LICENSE-2.0
 * 
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *****************************************************************************
 */

package com.alfresco.appcelerator.module.sdk;

import org.alfresco.mobile.android.api.model.Document;
import org.appcelerator.kroll.KrollProxy;
import org.appcelerator.kroll.annotations.Kroll;


@Kroll.proxy(creatableInModule = AndroidsdkmoduleModule.class,
 propertyAccessors = {"name", "title", "summary", "type", "createdBy", "createdAt", "modifiedBy", "modifiedAt", 
					  "contentMimeType", "contentLength", "versionLabel", "versionComment", "isLatestVersion"})
public class DocumentProxy extends KrollProxy 
{
	private Document document;
	
	public DocumentProxy()
	{
		super();
	}
	
	
	public DocumentProxy(Document doc)
	{
		this.document = doc;
		
		String nodeGetters[] = {"name", "title", "summary", "type", "createdBy", "createdAt", "modifiedBy", "modifiedAt"};    	
		String docGetters[] = {"contentStreamMimeType", "contentStreamLength", "versionLabel", "versionComment", "isLatestVersion"};
		String docPropertyNames[] = {"contentMimeType", "contentLength", null, null, null};	//For where they differ from iOS property names.
    	
		for (int i = 0;  i < nodeGetters.length;  i++)
		{
			Object value = SDKUtil.extractProperty(doc, nodeGetters[i]);
			if (value != null)
				setProperty(nodeGetters[i], value);
		}
		for (int i = 0;  i < docGetters.length;  i++)
		{
			Object value = SDKUtil.extractProperty(doc, docGetters[i]);
			if (value != null)
				setProperty(docPropertyNames[i] != null ? docPropertyNames[i] : docGetters[i], value);
		}
	}
	
	
	Document getDocument()
	{
		return document;
	}
}
 